@@ -18,9 +18,10 @@
  */
 
 #include "clipboard.h"
-#include <QGuiApplication>
-#include <QUrl>
 #include <QDebug>
+#include <QGuiApplication>
+#include <QMimeData>
+#include <QUrl>
 
 Clipboard::Clipboard(QObject* parent)
     : QObject(parent)
@@ -33,13 +34,13 @@ Clipboard::Clipboard(QObject* parent)
 void Clipboard::setMode(QClipboard::Mode mode)
 {
     m_mode = mode;
-    emit modeChanged(m_mode);
+    Q_EMIT modeChanged(m_mode);
 }
 
 void Clipboard::clipboardChanged(QClipboard::Mode m)
 {
     if (m == m_mode) {
-        emit contentChanged();
+        Q_EMIT contentChanged();
     }
 }
 
